package com.webratio.components.web.custom.stringsfunction;
import org.apache.commons.lang.StringUtils;
import org.dom4j.Element;

import com.webratio.rtx.RTXConstants;
import com.webratio.rtx.RTXException;
import com.webratio.rtx.RTXManager;
import com.webratio.rtx.beans.DefaultOperationBean;
import com.webratio.rtx.components.OperationService;
import com.webratio.rtx.context.NavigationContext;
import com.webratio.rtx.context.Scope;
import com.webratio.rtx.core.AbstractService;
import com.webratio.rtx.core.DescriptorHelper;


public class StringsFunctionComponentService extends AbstractService implements OperationService{
	
	private static final String MODE_UPPER_CASE_STRING = "uppercase";
    private static final String MODE_LOWER_CASE_STRING = "lowercase";
    private final String mode;
    
	public StringsFunctionComponentService(String id, RTXManager rtx, Element descr) throws RTXException {
        super(id, rtx, descr);
        this.mode = DescriptorHelper.getChildValue(descr, "Mode", true, this);
    }

    @Override
    public Object execute(NavigationContext context) throws RTXException {
    	DefaultOperationBean bean = new DefaultOperationBean();
    	try {
            if (MODE_UPPER_CASE_STRING.equals(mode)) {
                bean.put("resultString", StringUtils.upperCase(context.getString(getId() + ".string", Scope.REQUEST)));
            } else if (MODE_LOWER_CASE_STRING.equals(mode)) {
                bean.put("resultString", StringUtils.lowerCase(context.getString(getId() + ".string", Scope.REQUEST)));
            }
        } catch (Exception e) {
            logError("Unable to execute the function component service", e);
            bean.setResultCode(RTXConstants.ERROR_CODE);
            bean.put("errorMessage", e.getMessage());
            bean.put("exception", e);
            throw new RTXException(e);
        }
        return bean;
    }

}